@@ -1,6 +1,6 @@
 package Test::ConfigFromFile;
 use Moose;
 
-extends qw(MooseX::App::Cmd);
+extends 'MooseX::App::Cmd';
 
 1;
