@@ -2,7 +2,7 @@ package Test::ConfigFromFile::Command::moo;
 use Moose;
 use YAML();
 
-extends qw(MooseX::App::Cmd::Command);
+extends 'MooseX::App::Cmd::Command';
 with 'MooseX::ConfigFromFile';
 
 =head1 NAME
