@@ -1,7 +1,7 @@
 package Test::MyCmd::Command::justusage;
 use Moose;
 
-extends qw(MooseX::App::Cmd::Command);
+extends 'MooseX::App::Cmd::Command';
 
 =head1 NAME
 
